@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5881 $
-## |  Last changed: $Date: 2022-02-24 12:35:06 +0100 (Do, 24 Feb 2022) $
+## |  File version: $Revision: 6291 $
+## |  Last changed: $Date: 2022-06-13 08:36:13 +0200 (Mon, 13 Jun 2022) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -84,7 +84,7 @@ getDesignFisher <- function(...,
 
     cppEnabled <- .getOptionalArgument("cppEnabled", ..., optionalArgumentDefaultValue = TRUE)
     if (!cppEnabled) {
-        stop("The R version of getDesignFisher() is deprecated and no longer available in rpact")
+        stop("The cppEnabled option of  getDesignFisher() is deprecated and no longer available in rpact")
     }
 
     return(.getDesignFisher(
@@ -256,7 +256,6 @@ getDesignFisher <- function(...,
     design$.setParameterType("alphaSpent", C_PARAM_GENERATED)
     design$.setParameterType("nonStochasticCurtailment", C_PARAM_GENERATED)
 
-    maxIter <- NA_integer_
     tryCatch(
         {
             cases <- .getFisherCombinationCases(kMax = design$kMax, tVec = design$scale)
@@ -324,8 +323,11 @@ getDesignFisher <- function(...,
         }
 
         if (design$kMax > 1) {
-            if (any(na.omit(design$criticalValues[2:design$kMax] -
-                    design$criticalValues[1:(design$kMax - 1)]) > 1e-12)) {
+            diff <- na.omit(design$criticalValues[2:design$kMax] - design$criticalValues[1:(design$kMax - 1)])
+            if (length(diff) > 0 && any(diff > 1e-12)) {
+                .logDebug("Stop creation of Fisher design because critical values are ", 
+                    .arrayToString(criticalValues, vectorLookAndFeelEnabled = TRUE), ", ",
+                    "i.e., differences are ", .arrayToString(diff, vectorLookAndFeelEnabled = TRUE))
                 stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "no calculation possible")
             }
 
@@ -346,10 +348,6 @@ getDesignFisher <- function(...,
                 )
             }
         }
-
-        if (!is.na(maxIter) && maxIter < 0) {
-            stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "no calculation possible")
-        }
     }
 
     design$.setParameterType("simAlpha", C_PARAM_NOT_APPLICABLE)
