@@ -1,24 +1,24 @@
-#:#  
-#:#  *Unit tests*
-#:#  
-#:#  This file is part of the R package rpact:
-#:#  Confirmatory Adaptive Clinical Trial Design and Analysis
-#:#  
-#:#  Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD
-#:#  Licensed under "GNU Lesser General Public License" version 3
-#:#  License text can be found here: https://www.r-project.org/Licenses/LGPL-3
-#:#  
-#:#  RPACT company website: https://www.rpact.com
-#:#  RPACT package website: https://www.rpact.org
-#:#  
-#:#  Contact us for information about our services: info@rpact.com
-#:#  
-#:#  File name: test-f_simulation_base_rates.R
-#:#  Creation date: 18 May 2021, 17:48:05
-#:#  File version: $Revision: 4888 $
-#:#  Last changed: $Date: 2021-05-19 14:08:44 +0200 (Mi, 19 Mai 2021) $
-#:#  Last changed by: $Author: pahlke $
-#:#  
+## |  
+## |  *Unit tests*
+## |  
+## |  This file is part of the R package rpact:
+## |  Confirmatory Adaptive Clinical Trial Design and Analysis
+## |  
+## |  Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD
+## |  Licensed under "GNU Lesser General Public License" version 3
+## |  License text can be found here: https://www.r-project.org/Licenses/LGPL-3
+## |  
+## |  RPACT company website: https://www.rpact.com
+## |  RPACT package website: https://www.rpact.org
+## |  
+## |  Contact us for information about our services: info@rpact.com
+## |  
+## |  File name: test-f_simulation_base_rates.R
+## |  Creation date: 23 February 2022, 14:06:36
+## |  File version: $Revision: 5881 $
+## |  Last changed: $Date: 2022-02-24 12:35:06 +0100 (Do, 24 Feb 2022) $
+## |  Last changed by: $Author: pahlke $
+## |  
 
 context("Testing Simulation Rates Function")
 
@@ -27,13 +27,13 @@ test_that("'getSimulationRates': check several configurations", {
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:simulatingTestingOneHypothesis}
 	# @refFS[Tab.]{fs:tab:output:getSimulationRates}
-	# @refFS[Formula]{fs:SimulationOneArmRatesGenerate}
+	# @refFS[Formula]{fs:simulationOneArmRatesGenerate}
 	# @refFS[Formula]{fs:pValuesOneRateAlternativeGreater}
 	# @refFS[Formula]{fs:pValuesOneRateAlternativeSmaller}
-	# @refFS[Formula]{fs:SimulationTwoArmRatesGenerate}
+	# @refFS[Formula]{fs:simulationTwoArmRatesGenerate}
 	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeGreater}
-	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeSmaller} 
-	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeGreater} 
+	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeSmaller}
+	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeGreater}
 	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeSmaller}
 	# @refFS[Formula]{fs:testStatisticGroupSequential}
 	# @refFS[Formula]{fs:testStatisticNormalCombinationTest}
@@ -45,10 +45,14 @@ test_that("'getSimulationRates': check several configurations", {
 	informationRates <- (1:3) / 3
 	plannedSubjects <- round(informationRates * maxNumberOfSubjects)
 
-	x1 <- getSimulationRates(design = getDesignInverseNormal(futilityBounds = c(-0.5, 0.5), 
-		informationRates = informationRates), groups = 2, riskRatio = TRUE, thetaH0 = 0.8, 
-		plannedSubjects = plannedSubjects, maxNumberOfIterations = maxNumberOfIterations, 
-		allocationRatioPlanned = 3, seed = seed)
+	x1 <- getSimulationRates(
+	    design = getDesignInverseNormal(
+	        futilityBounds = c(-0.5, 0.5),
+	        informationRates = informationRates
+	    ), groups = 2, riskRatio = TRUE, thetaH0 = 0.8,
+	    plannedSubjects = plannedSubjects, maxNumberOfIterations = maxNumberOfIterations,
+	    allocationRatioPlanned = 3, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x1' with expected results
 	expect_equal(x1$effect, c(0.2, 0.7, 1.2, 1.7), tolerance = 1e-07)
@@ -86,12 +90,23 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x1CodeBased$expectedNumberOfSubjects, x1$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x1CodeBased$sampleSizes, x1$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x1CodeBased$conditionalPowerAchieved, x1$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x1), "character")
+	    df <- as.data.frame(x1)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x1)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
-	x2 <- getSimulationRates(design = getDesignInverseNormal(futilityBounds = c(-0.5, 0.5), 
-		informationRates = informationRates), groups = 2, riskRatio = FALSE, thetaH0 = -0.1, 
-		plannedSubjects = plannedSubjects, maxNumberOfIterations = maxNumberOfIterations, 
-		allocationRatioPlanned = 3, seed = seed)
+	x2 <- getSimulationRates(
+	    design = getDesignInverseNormal(
+	        futilityBounds = c(-0.5, 0.5),
+	        informationRates = informationRates
+	    ), groups = 2, riskRatio = FALSE, thetaH0 = -0.1,
+	    plannedSubjects = plannedSubjects, maxNumberOfIterations = maxNumberOfIterations,
+	    allocationRatioPlanned = 3, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x2' with expected results
 	expect_equal(x2$effect, c(0.1, 0.2, 0.3, 0.4), tolerance = 1e-07)
@@ -129,13 +144,24 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x2CodeBased$expectedNumberOfSubjects, x2$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x2CodeBased$sampleSizes, x2$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x2CodeBased$conditionalPowerAchieved, x2$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x2), "character")
+	    df <- as.data.frame(x2)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x2)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
 	.skipTestIfDisabled()
 
-	x3 <- getSimulationRates(design = getDesignInverseNormal(futilityBounds = c(-0.5, 0.5), 
-		informationRates = informationRates), groups = 1, thetaH0 = 0.2, pi1 = seq(0.2, 0.4, 0.05),  
-		plannedSubjects = plannedSubjects, maxNumberOfIterations = maxNumberOfIterations, seed = seed)
+	x3 <- getSimulationRates(
+	    design = getDesignInverseNormal(
+	        futilityBounds = c(-0.5, 0.5),
+	        informationRates = informationRates
+	    ), groups = 1, thetaH0 = 0.2, pi1 = seq(0.2, 0.4, 0.05),
+	    plannedSubjects = plannedSubjects, maxNumberOfIterations = maxNumberOfIterations, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x3' with expected results
 	expect_equal(x3$effect, c(0, 0.05, 0.1, 0.15, 0.2), tolerance = 1e-07)
@@ -173,13 +199,24 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x3CodeBased$expectedNumberOfSubjects, x3$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x3CodeBased$sampleSizes, x3$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x3CodeBased$conditionalPowerAchieved, x3$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x3), "character")
+	    df <- as.data.frame(x3)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x3)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
-	x4 <- getSimulationRates(design = getDesignInverseNormal(futilityBounds = c(0.5, 0.5), 
-		informationRates = informationRates), groups = 2, riskRatio = TRUE, thetaH0 = 1.5, 
-		pi1 = seq(0.05,0.25,0.05), plannedSubjects = plannedSubjects, 
-		maxNumberOfIterations = maxNumberOfIterations, directionUpper = FALSE, 
-		allocationRatioPlanned = 3, seed = seed)
+	x4 <- getSimulationRates(
+	    design = getDesignInverseNormal(
+	        futilityBounds = c(0.5, 0.5),
+	        informationRates = informationRates
+	    ), groups = 2, riskRatio = TRUE, thetaH0 = 1.5,
+	    pi1 = seq(0.05, 0.25, 0.05), plannedSubjects = plannedSubjects,
+	    maxNumberOfIterations = maxNumberOfIterations, directionUpper = FALSE,
+	    allocationRatioPlanned = 3, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x4' with expected results
 	expect_equal(x4$effect, c(-1.25, -1, -0.75, -0.5, -0.25), tolerance = 1e-07)
@@ -217,12 +254,23 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x4CodeBased$expectedNumberOfSubjects, x4$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x4CodeBased$sampleSizes, x4$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x4CodeBased$conditionalPowerAchieved, x4$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x4), "character")
+	    df <- as.data.frame(x4)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x4)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
-	x5 <- getSimulationRates(design = getDesignInverseNormal(futilityBounds = c(0.5, 0.5), 
-		informationRates = informationRates), groups = 2, riskRatio = FALSE, thetaH0 = 0.1, 
-		plannedSubjects = plannedSubjects, maxNumberOfIterations = maxNumberOfIterations, 
-		allocationRatioPlanned = 3, directionUpper = FALSE, seed = seed)
+	x5 <- getSimulationRates(
+	    design = getDesignInverseNormal(
+	        futilityBounds = c(0.5, 0.5),
+	        informationRates = informationRates
+	    ), groups = 2, riskRatio = FALSE, thetaH0 = 0.1,
+	    plannedSubjects = plannedSubjects, maxNumberOfIterations = maxNumberOfIterations,
+	    allocationRatioPlanned = 3, directionUpper = FALSE, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x5' with expected results
 	expect_equal(x5$effect, c(-0.1, 2.7755576e-17, 0.1, 0.2), tolerance = 1e-07)
@@ -260,12 +308,23 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x5CodeBased$expectedNumberOfSubjects, x5$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x5CodeBased$sampleSizes, x5$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x5CodeBased$conditionalPowerAchieved, x5$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x5), "character")
+	    df <- as.data.frame(x5)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x5)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
-	x6 <- getSimulationRates(design = getDesignInverseNormal(futilityBounds = c(0.5, 0.5), 
-		informationRates = informationRates), groups = 1, thetaH0 = 0.4, pi1 = seq(0.2, 0.4, 0.05),
-		plannedSubjects = plannedSubjects, directionUpper = FALSE, 
-		maxNumberOfIterations = maxNumberOfIterations, seed = seed)
+	x6 <- getSimulationRates(
+	    design = getDesignInverseNormal(
+	        futilityBounds = c(0.5, 0.5),
+	        informationRates = informationRates
+	    ), groups = 1, thetaH0 = 0.4, pi1 = seq(0.2, 0.4, 0.05),
+	    plannedSubjects = plannedSubjects, directionUpper = FALSE,
+	    maxNumberOfIterations = maxNumberOfIterations, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x6' with expected results
 	expect_equal(x6$effect, c(-0.2, -0.15, -0.1, -0.05, 0), tolerance = 1e-07)
@@ -303,14 +362,23 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x6CodeBased$expectedNumberOfSubjects, x6$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x6CodeBased$sampleSizes, x6$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x6CodeBased$conditionalPowerAchieved, x6$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x6), "character")
+	    df <- as.data.frame(x6)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x6)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
-	x7 <- getSimulationRates(design = getDesignInverseNormal(futilityBounds = c(0.5), typeOfDesign = "P"), 
-		thetaH0 = 0.3, groups = 1, plannedSubjects = c(30,60), 
-		pi1 = seq(0.3,0.5,0.05),maxNumberOfIterations = maxNumberOfIterations, 
-		conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(30, 30), 
-		maxNumberOfSubjectsPerStage = 5 * c(NA, 30), 
-		directionUpper = TRUE, seed = seed)
+	x7 <- getSimulationRates(
+	    design = getDesignInverseNormal(futilityBounds = c(0.5), typeOfDesign = "P"),
+	    thetaH0 = 0.3, groups = 1, plannedSubjects = c(30, 60),
+	    pi1 = seq(0.3, 0.5, 0.05), maxNumberOfIterations = maxNumberOfIterations,
+	    conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(30, 30),
+	    maxNumberOfSubjectsPerStage = 5 * c(NA, 30),
+	    directionUpper = TRUE, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x7' with expected results
 	expect_equal(x7$effect, c(0, 0.05, 0.1, 0.15, 0.2), tolerance = 1e-07)
@@ -319,7 +387,6 @@ test_that("'getSimulationRates': check several configurations", {
 	expect_equal(x7$overallReject, c(0.05, 0.18, 0.47, 0.77, 0.91), tolerance = 1e-07)
 	expect_equal(x7$rejectPerStage[1, ], c(0.02, 0.06, 0.15, 0.36, 0.59), tolerance = 1e-07)
 	expect_equal(x7$rejectPerStage[2, ], c(0.03, 0.12, 0.32, 0.41, 0.32), tolerance = 1e-07)
-	expect_equal(x7$futilityStop, c(0.73, 0.53, 0.32, 0.14, 0.06), tolerance = 1e-07)
 	expect_equal(x7$futilityPerStage[1, ], c(0.73, 0.53, 0.32, 0.14, 0.06), tolerance = 1e-07)
 	expect_equal(x7$earlyStop, c(0.75, 0.59, 0.47, 0.5, 0.65), tolerance = 1e-07)
 	expect_equal(x7$expectedNumberOfSubjects, c(58.56, 77.43, 83.21, 80.96, 58.83), tolerance = 1e-07)
@@ -337,21 +404,30 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x7CodeBased$iterations, x7$iterations, tolerance = 1e-05)
 	    expect_equal(x7CodeBased$overallReject, x7$overallReject, tolerance = 1e-05)
 	    expect_equal(x7CodeBased$rejectPerStage, x7$rejectPerStage, tolerance = 1e-05)
-	    expect_equal(x7CodeBased$futilityStop, x7$futilityStop, tolerance = 1e-05)
 	    expect_equal(x7CodeBased$futilityPerStage, x7$futilityPerStage, tolerance = 1e-05)
 	    expect_equal(x7CodeBased$earlyStop, x7$earlyStop, tolerance = 1e-05)
 	    expect_equal(x7CodeBased$expectedNumberOfSubjects, x7$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x7CodeBased$sampleSizes, x7$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x7CodeBased$conditionalPowerAchieved, x7$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x7), "character")
+	    df <- as.data.frame(x7)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x7)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
-	x8 <- getSimulationRates(design = getDesignGroupSequential(
-		futilityBounds = c(0.5, 0.5), typeOfDesign = "P"), 
-		thetaH0 = 0.3, groups = 2, allocationRatioPlanned = 3, plannedSubjects = (1:3) * 100, 
-		pi1 = seq(0.2, 0.4, 0.05), pi2 = 0.2, maxNumberOfIterations = maxNumberOfIterations, 
-		conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(100, 100, 100), 
-		maxNumberOfSubjectsPerStage = 5 * c(NA, 100, 100), 
-		directionUpper = FALSE, seed = seed)
+	x8 <- getSimulationRates(
+	    design = getDesignGroupSequential(
+	        futilityBounds = c(0.5, 0.5), typeOfDesign = "P"
+	    ),
+	    thetaH0 = 0.3, groups = 2, allocationRatioPlanned = 3, plannedSubjects = (1:3) * 100,
+	    pi1 = seq(0.2, 0.4, 0.05), pi2 = 0.2, maxNumberOfIterations = maxNumberOfIterations,
+	    conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(100, 100, 100),
+	    maxNumberOfSubjectsPerStage = 5 * c(NA, 100, 100),
+	    directionUpper = FALSE, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x8' with expected results
 	expect_equal(x8$effect, c(-0.3, -0.25, -0.2, -0.15, -0.1), tolerance = 1e-07)
@@ -389,15 +465,25 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x8CodeBased$expectedNumberOfSubjects, x8$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x8CodeBased$sampleSizes, x8$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x8CodeBased$conditionalPowerAchieved, x8$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x8), "character")
+	    df <- as.data.frame(x8)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x8)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
-	x9 <- getSimulationRates(design = getDesignGroupSequential(
-		futilityBounds = c(0), typeOfDesign = "P"), 
-		thetaH0 = 0.8, groups = 2, riskRatio = TRUE, allocationRatioPlanned = 3, 
-		maxNumberOfIterations = maxNumberOfIterations,
-		plannedSubjects = c(100,200), pi1 = seq(0.15, 0.4, 0.05), pi2 = 0.2, 
-		conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(100, 100), 
-		maxNumberOfSubjectsPerStage = 5*c(NA, 100), directionUpper = TRUE, seed = seed)
+	x9 <- getSimulationRates(
+	    design = getDesignGroupSequential(
+	        futilityBounds = c(0), typeOfDesign = "P"
+	    ),
+	    thetaH0 = 0.8, groups = 2, riskRatio = TRUE, allocationRatioPlanned = 3,
+	    maxNumberOfIterations = maxNumberOfIterations,
+	    plannedSubjects = c(100, 200), pi1 = seq(0.15, 0.4, 0.05), pi2 = 0.2,
+	    conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(100, 100),
+	    maxNumberOfSubjectsPerStage = 5 * c(NA, 100), directionUpper = TRUE, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x9' with expected results
 	expect_equal(x9$effect, c(-0.05, 0.2, 0.45, 0.7, 0.95, 1.2), tolerance = 1e-07)
@@ -406,7 +492,6 @@ test_that("'getSimulationRates': check several configurations", {
 	expect_equal(x9$overallReject, c(0.01, 0.07, 0.45, 0.86, 0.92, 1), tolerance = 1e-07)
 	expect_equal(x9$rejectPerStage[1, ], c(0.01, 0.02, 0.11, 0.24, 0.41, 0.65), tolerance = 1e-07)
 	expect_equal(x9$rejectPerStage[2, ], c(0, 0.05, 0.34, 0.62, 0.51, 0.35), tolerance = 1e-07)
-	expect_equal(x9$futilityStop, c(0.51, 0.32, 0.14, 0.02, 0.02, 0), tolerance = 1e-07)
 	expect_equal(x9$futilityPerStage[1, ], c(0.51, 0.32, 0.14, 0.02, 0.02, 0), tolerance = 1e-07)
 	expect_equal(x9$earlyStop, c(0.52, 0.34, 0.25, 0.26, 0.43, 0.65), tolerance = 1e-07)
 	expect_equal(x9$expectedNumberOfSubjects, c(323.82, 368.88, 387.13, 364.4, 246.27, 193.96), tolerance = 1e-07)
@@ -424,41 +509,51 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x9CodeBased$iterations, x9$iterations, tolerance = 1e-05)
 	    expect_equal(x9CodeBased$overallReject, x9$overallReject, tolerance = 1e-05)
 	    expect_equal(x9CodeBased$rejectPerStage, x9$rejectPerStage, tolerance = 1e-05)
-	    expect_equal(x9CodeBased$futilityStop, x9$futilityStop, tolerance = 1e-05)
 	    expect_equal(x9CodeBased$futilityPerStage, x9$futilityPerStage, tolerance = 1e-05)
 	    expect_equal(x9CodeBased$earlyStop, x9$earlyStop, tolerance = 1e-05)
 	    expect_equal(x9CodeBased$expectedNumberOfSubjects, x9$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x9CodeBased$sampleSizes, x9$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x9CodeBased$conditionalPowerAchieved, x9$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x9), "character")
+	    df <- as.data.frame(x9)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x9)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
-	calcSubjectsFunctionSimulationBaseRates <- function(...,stage,
-		plannedSubjects,
-		minNumberOfSubjectsPerStage,
-		maxNumberOfSubjectsPerStage,
-		conditionalPower,
-		conditionalCriticalValue,
-		overallRate) {
-		if (overallRate[1] - overallRate[2] < 0.1) {
-			return(plannedSubjects[stage] - plannedSubjects[stage - 1]) 
-		} else {
-			rateUnderH0 <- (overallRate[1] + overallRate[2])/2 
-			stageSubjects <- 2 * (max(0, conditionalCriticalValue * 
-							sqrt(2 * rateUnderH0 * (1 - rateUnderH0)) + 
-							stats::qnorm(conditionalPower) * sqrt(overallRate[1] * (1 - overallRate[1]) +
-									overallRate[2] * (1 - overallRate[2]))))^2 /
-				(max(1e-12,	(overallRate[1] - overallRate[2])))^2
-			stageSubjects <- ceiling(min(max(minNumberOfSubjectsPerStage[stage], 
-						stageSubjects), maxNumberOfSubjectsPerStage[stage]))
-			return(stageSubjects)
-		}	
+	calcSubjectsFunctionSimulationBaseRates <- function(..., stage,
+	        plannedSubjects,
+	        minNumberOfSubjectsPerStage,
+	        maxNumberOfSubjectsPerStage,
+	        conditionalPower,
+	        conditionalCriticalValue,
+	        overallRate) {
+	    if (overallRate[1] - overallRate[2] < 0.1) {
+	        return(plannedSubjects[stage] - plannedSubjects[stage - 1])
+	    } else {
+	        rateUnderH0 <- (overallRate[1] + overallRate[2]) / 2
+	        stageSubjects <- 2 * (max(0, conditionalCriticalValue *
+	            sqrt(2 * rateUnderH0 * (1 - rateUnderH0)) +
+	            stats::qnorm(conditionalPower) * sqrt(overallRate[1] * (1 - overallRate[1]) +
+	                overallRate[2] * (1 - overallRate[2]))))^2 /
+	            (max(1e-12, (overallRate[1] - overallRate[2])))^2
+	        stageSubjects <- ceiling(min(max(
+	            minNumberOfSubjectsPerStage[stage],
+	            stageSubjects
+	        ), maxNumberOfSubjectsPerStage[stage]))
+	        return(stageSubjects)
+	    }
 	}
-	x10 <- getSimulationRates(design = getDesignInverseNormal(kMax = 2), 
-		pi1 = seq(0.3,0.6,0.1), pi2 = 0.3, plannedSubjects = c(40, 80), 
-		minNumberOfSubjectsPerStage = c(40, 20), 
-		maxNumberOfSubjectsPerStage = c(40, 160),
-		conditionalPower = 0.8,	calcSubjectsFunction = calcSubjectsFunctionSimulationBaseRates, 
-		maxNumberOfIterations = maxNumberOfIterations, seed = seed)
+	x10 <- getSimulationRates(
+	    design = getDesignInverseNormal(kMax = 2),
+	    pi1 = seq(0.3, 0.6, 0.1), pi2 = 0.3, plannedSubjects = c(40, 80),
+	    minNumberOfSubjectsPerStage = c(40, 20),
+	    maxNumberOfSubjectsPerStage = c(40, 160),
+	    conditionalPower = 0.8, calcSubjectsFunction = calcSubjectsFunctionSimulationBaseRates,
+	    maxNumberOfIterations = maxNumberOfIterations, seed = seed
+	)
 
 	## Comparison of the results of SimulationResultsRates object 'x10' with expected results
 	expect_equal(x10$effect, c(0, 0.1, 0.2, 0.3), tolerance = 1e-07)
@@ -467,7 +562,6 @@ test_that("'getSimulationRates': check several configurations", {
 	expect_equal(x10$overallReject, c(0.02, 0.2, 0.52, 0.89), tolerance = 1e-07)
 	expect_equal(x10$rejectPerStage[1, ], c(0, 0.01, 0.05, 0.25), tolerance = 1e-07)
 	expect_equal(x10$rejectPerStage[2, ], c(0.02, 0.19, 0.47, 0.64), tolerance = 1e-07)
-	expect_equal(x10$futilityStop, c(0, 0, 0, 0))
 	expect_equal(x10$futilityPerStage[1, ], c(0, 0, 0, 0))
 	expect_equal(x10$earlyStop, c(0, 0.01, 0.05, 0.25), tolerance = 1e-07)
 	expect_equal(x10$expectedNumberOfSubjects, c(104.34, 113.7, 101.87, 83.69), tolerance = 1e-07)
@@ -485,12 +579,18 @@ test_that("'getSimulationRates': check several configurations", {
 	    expect_equal(x10CodeBased$iterations, x10$iterations, tolerance = 1e-05)
 	    expect_equal(x10CodeBased$overallReject, x10$overallReject, tolerance = 1e-05)
 	    expect_equal(x10CodeBased$rejectPerStage, x10$rejectPerStage, tolerance = 1e-05)
-	    expect_equal(x10CodeBased$futilityStop, x10$futilityStop, tolerance = 1e-05)
 	    expect_equal(x10CodeBased$futilityPerStage, x10$futilityPerStage, tolerance = 1e-05)
 	    expect_equal(x10CodeBased$earlyStop, x10$earlyStop, tolerance = 1e-05)
 	    expect_equal(x10CodeBased$expectedNumberOfSubjects, x10$expectedNumberOfSubjects, tolerance = 1e-05)
 	    expect_equal(x10CodeBased$sampleSizes, x10$sampleSizes, tolerance = 1e-05)
 	    expect_equal(x10CodeBased$conditionalPowerAchieved, x10$conditionalPowerAchieved, tolerance = 1e-05)
+	    expect_type(names(x10), "character")
+	    df <- as.data.frame(x10)
+	    expect_s3_class(df, "data.frame")
+	    expect_true(nrow(df) > 0 && ncol(df) > 0)
+	    mtx <- as.matrix(x10)
+	    expect_true(is.matrix(mtx))
+	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
 })
@@ -503,25 +603,28 @@ test_that("'getSimulationRates': comparison with getPowerRates() results for a i
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:simulatingTestingOneHypothesis}
 	# @refFS[Tab.]{fs:tab:output:getSimulationRates}
-	# @refFS[Formula]{fs:SimulationOneArmRatesGenerate}
+	# @refFS[Formula]{fs:simulationOneArmRatesGenerate}
 	# @refFS[Formula]{fs:pValuesOneRateAlternativeGreater}
 	# @refFS[Formula]{fs:pValuesOneRateAlternativeSmaller}
-	# @refFS[Formula]{fs:SimulationTwoArmRatesGenerate}
+	# @refFS[Formula]{fs:simulationTwoArmRatesGenerate}
 	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeGreater}
-	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeSmaller} 
-	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeGreater} 
+	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeSmaller}
+	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeGreater}
 	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeSmaller}
 	# @refFS[Formula]{fs:testStatisticGroupSequential}
 	# @refFS[Formula]{fs:testStatisticNormalCombinationTest}
 	# @refFS[Formula]{fs:testStatisticFisherCombinationTest}
 	design <- getDesignInverseNormal(futilityBounds = c(-1), informationRates = c(0.5, 1), typeOfDesign = "P")
-	x <- getSimulationRates(design, 
-		thetaH0 = 0.4, groups = 1, plannedSubjects = c(150, 300), pi1 = seq(0.3, 0.4, 0.02), 
-		maxNumberOfIterations = 1000, 
-		conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(NA_real_, 100), 
-		maxNumberOfSubjectsPerStage = c(NA_real_, 500), directionUpper = FALSE, seed = 123)
-	y <- getPowerRates(design, thetaH0 = 0.4, groups = 1, pi1 = seq(0.3, 0.4, 0.02), 
-		directionUpper = FALSE, maxNumberOfSubjects = 300)
+	x <- getSimulationRates(design,
+	    thetaH0 = 0.4, groups = 1, plannedSubjects = c(150, 300), pi1 = seq(0.3, 0.4, 0.02),
+	    maxNumberOfIterations = 1000,
+	    conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(NA_real_, 100),
+	    maxNumberOfSubjectsPerStage = c(NA_real_, 500), directionUpper = FALSE, seed = 123
+	)
+	y <- getPowerRates(design,
+	    thetaH0 = 0.4, groups = 1, pi1 = seq(0.3, 0.4, 0.02),
+	    directionUpper = FALSE, maxNumberOfSubjects = 300
+	)
 
 	expectedNumberOfSubjectsDiff <- round((x$expectedNumberOfSubjects - y$expectedNumberOfSubjects) / 300, 4)
 
@@ -554,24 +657,26 @@ test_that("'getSimulationRates': comparison with getPowerRates() results for a g
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:simulatingTestingOneHypothesis}
 	# @refFS[Tab.]{fs:tab:output:getSimulationRates}
-	# @refFS[Formula]{fs:SimulationTwoArmRatesGenerate}
+	# @refFS[Formula]{fs:simulationTwoArmRatesGenerate}
 	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeGreater}
-	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeSmaller} 
-	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeGreater} 
+	# @refFS[Formula]{fs:pValuesTwoRatesAlternativeSmaller}
+	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeGreater}
 	# @refFS[Formula]{fs:pValuesTwoRatesApproximationAlternativeSmaller}
 	# @refFS[Formula]{fs:testStatisticGroupSequential}
 	# @refFS[Formula]{fs:testStatisticNormalCombinationTest}
 	# @refFS[Formula]{fs:testStatisticFisherCombinationTest}
-	design <- getDesignGroupSequential(futilityBounds = c(-1,1), typeOfDesign = "P")
-	x <- getSimulationRates(design, 
-		thetaH0 = 0.3, groups = 2, allocationRatioPlanned = 2, plannedSubjects = (1:3)*100, 
-		pi1 = seq(0.2, 0.4, 0.05), pi2 = 0.1, 
-		conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(100, 100, 100), 
-		maxNumberOfSubjectsPerStage = 1*c(100, 100, 100), directionUpper = FALSE, seed = 123)
+	design <- getDesignGroupSequential(futilityBounds = c(-1, 1), typeOfDesign = "P")
+	x <- getSimulationRates(design,
+	    thetaH0 = 0.3, groups = 2, allocationRatioPlanned = 2, plannedSubjects = (1:3) * 100,
+	    pi1 = seq(0.2, 0.4, 0.05), pi2 = 0.1,
+	    conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(100, 100, 100),
+	    maxNumberOfSubjectsPerStage = 1 * c(100, 100, 100), directionUpper = FALSE, seed = 123
+	)
 
-	y <- getPowerRates(design, 
-		thetaH0 = 0.3, groups = 2, allocationRatioPlanned = 2, pi1 = seq(0.2, 0.4, 0.05), 
-		pi2 = 0.1, directionUpper = FALSE, maxNumberOfSubjects = 300)
+	y <- getPowerRates(design,
+	    thetaH0 = 0.3, groups = 2, allocationRatioPlanned = 2, pi1 = seq(0.2, 0.4, 0.05),
+	    pi2 = 0.1, directionUpper = FALSE, maxNumberOfSubjects = 300
+	)
 
 	expectedNumberOfSubjectsDiff <- round((x$expectedNumberOfSubjects - y$expectedNumberOfSubjects) / 300, 4)
 
@@ -596,19 +701,23 @@ test_that("'getSimulationRates': comparison with getPowerRates() results for a g
 	expect_equal(futilityPerStageDiff[1, ], c(-1e-04, 0, 0.0049, 0.0058, 0.0053), tolerance = 1e-07)
 	expect_equal(futilityPerStageDiff[2, ], c(0.0018, 0.0077, -0.0146, -0.0016, -0.0038), tolerance = 1e-07)
 
-	##--
+	## --
 
-	x2 <- getSimulationRates(design = getDesignGroupSequential(futilityBounds = c(-1, 1), typeOfDesign = "P"), 
-		thetaH0 = 0.8, groups = 2, riskRatio = TRUE, allocationRatioPlanned = 2, 
-		plannedSubjects = c(100, 200, 300), pi1 = seq(0.15,0.4,0.05), pi2 = 0.2, 
-		conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(NA_real_, 150, 300), 
-		maxNumberOfSubjectsPerStage = c(NA_real_, 200, 300), directionUpper = TRUE, 
-		maxNumberOfIterations = 1000, seed = 123)
+	x2 <- getSimulationRates(
+	    design = getDesignGroupSequential(futilityBounds = c(-1, 1), typeOfDesign = "P"),
+	    thetaH0 = 0.8, groups = 2, riskRatio = TRUE, allocationRatioPlanned = 2,
+	    plannedSubjects = c(100, 200, 300), pi1 = seq(0.15, 0.4, 0.05), pi2 = 0.2,
+	    conditionalPower = 0.8, minNumberOfSubjectsPerStage = c(NA_real_, 150, 300),
+	    maxNumberOfSubjectsPerStage = c(NA_real_, 200, 300), directionUpper = TRUE,
+	    maxNumberOfIterations = 1000, seed = 123
+	)
 
-	y2 <- getPowerRates(design = getDesignGroupSequential(futilityBounds = c(-1, 1), typeOfDesign = "P"), 
-		thetaH0 = 0.8, groups = 2, riskRatio = TRUE, allocationRatioPlanned = 2, 
-		pi1 = seq(0.15, 0.4, 0.05), pi2 = 0.2, maxNumberOfSubjects = 300, 
-		directionUpper = TRUE)
+	y2 <- getPowerRates(
+	    design = getDesignGroupSequential(futilityBounds = c(-1, 1), typeOfDesign = "P"),
+	    thetaH0 = 0.8, groups = 2, riskRatio = TRUE, allocationRatioPlanned = 2,
+	    pi1 = seq(0.15, 0.4, 0.05), pi2 = 0.2, maxNumberOfSubjects = 300,
+	    directionUpper = TRUE
+	)
 
 	expectedNumberOfSubjectsDiff2 <- round((x2$expectedNumberOfSubjects - y2$expectedNumberOfSubjects) / 300, 4)
 
@@ -632,6 +741,5 @@ test_that("'getSimulationRates': comparison with getPowerRates() results for a g
 	## Comparison of the results of matrixarray object 'futilityPerStageDiff2' with expected results
 	expect_equal(futilityPerStageDiff2[1, ], c(-0.0028, -0.016, -0.0034, -3e-04, -5e-04, -1e-04), tolerance = 1e-07)
 	expect_equal(futilityPerStageDiff2[2, ], c(-0.0068, -0.0474, -0.0917, -0.0386, -0.0101, -0.0011), tolerance = 1e-07)
-
 })
 
